@@ -213,15 +213,6 @@ sjp.lmm <- function(...,
   # --------------------------------------------------------
   # unlist labels
   # --------------------------------------------------------
-  # Help function that unlists a list into a vector
-  unlistlabels <- function(lab) {
-    dummy <- unlist(lab)
-    labels <- c()
-    for (i in 1:length(dummy)) {
-      labels <- c(labels, as.character(dummy[i]))
-    }
-    return (labels)
-  }
   # unlist axis labels (predictors)
   if (!is.null(axisLabels.y) && is.list(axisLabels.y)) {
     axisLabels.y <- unlistlabels(axisLabels.y)
@@ -230,8 +221,6 @@ sjp.lmm <- function(...,
   if (!is.null(labelDependentVariables) && is.list(labelDependentVariables)) {
     labelDependentVariables <- unlistlabels(labelDependentVariables)
   }
-  
-  
   # ----------------------------
   # init final data frame
   # ----------------------------
@@ -303,7 +292,7 @@ sjp.lmm <- function(...,
     # ----------------------------
     if (showValueLabels) {
       for (i in 1:length(pv)) {
-        ps[i] <- c(round(ov[i],labelDigits))
+        ps[i] <- sprintf("%.*f", labelDigits, ov[i])
       }
     }
     # ----------------------------
@@ -401,15 +390,6 @@ sjp.lmm <- function(...,
   else {
     ticks <- c(seq(lower_lim, upper_lim, by=gridBreaksAt))
   }
-  # --------------------------------------
-  # Formatierungen: Generell bei ggplot gilt: "fill"-Wert in
-  # "aes"-Parameter der ggplot-Funktion bezieht sich darauf,
-  # welche Werte eine neue Farbe kriegen sollen (mapping).
-  # Innerhalb von geom_bar etc. bezieht sich der "fill"-Parameter
-  # auf die verschiedenen Farbwerte, die gesetzt werden sollen.
-  # --------------------------------------
-  
-  
   # --------------------------------------------------------
   # define bar / line colors
   # --------------------------------------------------------
@@ -442,8 +422,6 @@ sjp.lmm <- function(...,
   else {
     scalecolors <- scale_colour_manual(values=barcols, labels=labelDependentVariables)
   }
-  
-  
   # --------------------------------------------------------
   # Set theme and default grid colours. grid colours
   # might be adjusted later
@@ -468,8 +446,6 @@ sjp.lmm <- function(...,
     minorGridColor <- c("white")
     showTickMarks <-FALSE
   }
-  
-  
   # --------------------------------------------------------
   # Set up grid colours
   # --------------------------------------------------------
@@ -482,8 +458,6 @@ sjp.lmm <- function(...,
     minorgrid <- element_line(colour=minorGridColor)
   }
   hidegrid <- element_line(colour=hideGridColor)
-  
-  
   # --------------------------------------------------------
   # Set up visibility oftick marks
   # --------------------------------------------------------
@@ -493,8 +467,6 @@ sjp.lmm <- function(...,
   if (!showAxisLabels.y) {
     axisLabels.y <- c("")
   }
-  
-  
   # --------------------------------------------------------
   # body of plot
   # --------------------------------------------------------
