@@ -37,6 +37,18 @@
 #'          default is \code{"Intercept"}.
 #' @param stringObservations String constant used in the summary row for the count of observation
 #'          (cases). Default is \code{"Observations"}.
+#' @param stringOR String used for the column heading of odds ratio values. Default is \code{"OR"}.
+#' @param stringCI String used for the column heading of confidence interval values. Default is \code{"CI"}.
+#' @param stringSE String used for the column heading of standard error values. Default is \code{"std. Error"}.
+#' @param stringP String used for the column heading of p values. Default is \code{"p"}.
+#' @param digits.est Amount of decimals for estimators.
+#' @param digits.p Amount of decimals for p-values.
+#' @param digits.ci Amount of decimals for confidence intervals.
+#' @param digits.se Amount of decimals for standard error.
+#' @param digits.summary Amount of decimals for values in model summary.
+#' @param exp.coef If \code{TRUE} (default), regression coefficients and confidence intervals are exponentiated
+#'          (\code{\link{exp}(\link{coef}(fit))}. Use \code{FALSE} if you want the non-exponentiated coefficients
+#'          as they are provided by the \code{\link{summary}} function.
 #' @param pvaluesAsNumbers If \code{TRUE}, p-values are shown as numbers. If \code{FALSE} (default),
 #'          p-values are indicated by asterisks.
 #' @param boldpvalues If \code{TRUE} (default), significant p-values are shown bold faced.
@@ -46,6 +58,9 @@
 #'          Default is \code{FALSE}.
 #' @param separateConfColumn if \code{TRUE}, the CI values are shown in a separate table column.
 #'          Default is \code{FALSE}.
+#' @param newLineConf If \code{TRUE} and \code{separateConfColumn} is \code{FALSE}, inserts a line break
+#'          between OR and CI values. If \code{FALSE}, CI values are printed in the same
+#'          line with OR values.
 #' @param showAbbrHeadline If \code{TRUE} (default), the table data columns have a headline with 
 #'          abbreviations for odds ratios, confidence interval and p-values.
 #' @param showPseudoR If \code{TRUE} (default), the pseudo R2 values for each model are printed
@@ -62,6 +77,10 @@
 #'          and same predictors and response, to decide which model fits best. See \code{\link{family}}
 #'          for more details. It is recommended to inspect the model \code{\link{AIC}} (see \code{showAIC}) to get a
 #'          decision help for which model to choose.
+#' @param cellSpacing The inner padding of table cells. By default, this value is 0.2 (measure is cm), which is
+#'          suitable for viewing the table. Decrease this value (0.05 to 0.1) if you want to import the table
+#'          into Office documents. This is a convenient parameter for the \code{CSS} parameter for changing
+#'          cell spacing, which would be: \code{CSS=list(css.thead="padding:0.2cm;", css.tzdata="padding:0.2cm;")}.
 #' @param encoding The charset encoding used for variable and value labels. Default is \code{"UTF-8"}. Change
 #'          encoding if specific chars are not properly displayed (e.g.) German umlauts).
 #' @param CSS A \code{\link{list}} with user-defined style-sheet-definitions, according to the official CSS syntax (see
@@ -179,17 +198,29 @@ sjt.glm <- function (...,
                      stringModel="Model",
                      stringIntercept="(Intercept)",
                      stringObservations="Observations",
+                     stringOR="OR",
+                     stringCI="CI",
+                     stringSE="std. Error",
+                     stringP="p",
+                     digits.est=2,
+                     digits.p=3,
+                     digits.ci=2,
+                     digits.se=2,
+                     digits.summary=3,
+                     exp.coef=TRUE,
                      pvaluesAsNumbers=FALSE,
                      boldpvalues=TRUE,
                      showConfInt=TRUE,
                      showStdError=FALSE,
                      separateConfColumn=FALSE,
+                     newLineConf=TRUE,
                      showAbbrHeadline=TRUE,
                      showPseudoR=TRUE,
                      showLogLik=FALSE,
                      showAIC=FALSE,
                      showChi2=FALSE,
                      showFamily=FALSE,
+                     cellSpacing=0.2,
                      encoding="UTF-8",
                      CSS=NULL,
                      useViewer=TRUE,
@@ -220,8 +251,8 @@ sjt.glm <- function (...,
   tag.leftalign <- "leftalign"
   tag.centeralign <- "centeralign"
   css.table <- "border-collapse:collapse; border:none;"
-  css.thead <- "border-bottom: 1px solid; padding:0.2cm;"
-  css.tdata <- "padding:0.2cm;"
+  css.thead <- sprintf("border-bottom: 1px solid; padding:%.1fcm;", cellSpacing)
+  css.tdata <- sprintf("padding:%.1fcm;", cellSpacing)
   css.summary <- "padding-top:0.1cm; padding-bottom:0.1cm;"
   css.colnames <- "font-style:italic;"
   css.firstsumrow <- "border-top:1px solid;"
@@ -286,10 +317,10 @@ sjt.glm <- function (...,
   # -------------------------------------
   if (!showConfInt) {
     separateConfColumn <- FALSE
-    showCIString <- c("OR")
+    showCIString <- stringOR
   }
   else {
-    showCIString <- c("OR (CI)")
+    showCIString <- sprintf("%s (%s)", stringOR, stringCI)
   }
   # -------------------------------------
   # table headline
@@ -301,6 +332,8 @@ sjt.glm <- function (...,
   if (showStdError) headerColSpanFactor <- headerColSpanFactor+1
   
   headerColSpan <- headerColSpanFactor * headerColSpan
+  linebreakstring <- " "
+  if (newLineConf) linebreakstring <- "<br>"
   # -------------------------------------
   # start table
   # -------------------------------------
@@ -365,12 +398,19 @@ sjt.glm <- function (...,
   # -------------------------------------
   for (i in 1:length(input_list)) {
     fit <- input_list[[i]]
-    coeffs <- rbind(coeffs, exp(coef(fit)))
-    confi_lower <- cbind(confi_lower, exp(confint(fit))[,1])
-    confi_higher <- cbind(confi_higher, exp(confint(fit))[,2])
-    pv <- cbind(pv, round(summary(fit)$coefficients[,4],3))
+    if (exp.coef) {
+      coeffs <- rbind(coeffs, exp(coef(fit)))
+      confi_lower <- cbind(confi_lower, exp(confint(fit))[,1])
+      confi_higher <- cbind(confi_higher, exp(confint(fit))[,2])
+    }
+    else {
+      coeffs <- rbind(coeffs, coef(fit))
+      confi_lower <- cbind(confi_lower, confint(fit)[,1])
+      confi_higher <- cbind(confi_higher, confint(fit)[,2])
+    }
+    pv <- cbind(pv, round(summary(fit)$coefficients[,4],digits.p))
     # standard error
-    se <- cbind(se, round(summary(fit)$coefficients[,2],2))
+    se <- cbind(se, round(summary(fit)$coefficients[,2],digits.se))
   }
   # -------------------------------------
   # rotate coefficients
@@ -396,9 +436,9 @@ sjt.glm <- function (...,
   else {
     pv <- apply(pv, c(1,2), function(x) {
       if (x <0.05 && boldpvalues) {
-        x <- sprintf("<b>%.3f</b>", x)      }
+        x <- sprintf("<b>%.*f</b>", digits.p, x)      }
       else {
-        x <- sprintf("%.3f", x) 
+        x <- sprintf("%.*f", digits.p, x) 
       }
     })
   }
@@ -411,17 +451,17 @@ sjt.glm <- function (...,
     for (i in 1:colnr) {
       # confidence interval in separate column
       if (separateConfColumn) {
-        page.content <- paste0(page.content, "\n    <td class=\"tdata centeralign colnames\">OR</td>")
-        if (showConfInt) page.content <- paste0(page.content, "<td class=\"tdata centeralign colnames\">CI</td>")
+        page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign colnames\">%s</td>", stringOR))
+        if (showConfInt) page.content <- paste0(page.content, sprintf("<td class=\"tdata centeralign colnames\">%s</td>", stringCI))
       }
       else {
         # confidence interval in Beta-column
         page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign colnames\">%s</td>", showCIString))
       }
       # show std. error
-      if (showStdError) page.content <- paste0(page.content, "<td class=\"tdata centeralign colnames\">std. Error</td>")
+      if (showStdError) page.content <- paste0(page.content, sprintf("<td class=\"tdata centeralign colnames\">%s</td>", stringSE))
       # show p-values as numbers in separate column
-      if (pvaluesAsNumbers) page.content <- paste0(page.content, "<td class=\"tdata centeralign colnames\">p</td>")
+      if (pvaluesAsNumbers) page.content <- paste0(page.content, sprintf("<td class=\"tdata centeralign colnames\">%s</td>", stringP))
     }
     page.content <- paste(page.content, "\n  </tr>\n")
   }
@@ -437,12 +477,12 @@ sjt.glm <- function (...,
     # confidence interval in separate column
     if (separateConfColumn) {
       # open table cell for Beta-coefficient
-      page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign topcontentborder\">%.2f", coeffs[1,i]))
+      page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign topcontentborder\">%.*f", digits.est, coeffs[1,i]))
       # if p-values are not shown as numbers, insert them after beta-value
       if (!pvaluesAsNumbers) page.content <- paste0(page.content, sprintf(" %s", pv[1,i]))
       # if we have CI, start new table cell (CI in separate column)
       if (showConfInt) {
-        page.content <- paste0(page.content, sprintf("</td><td class=\"tdata centeralign topcontentborder\">%.2f-%.2f</td>", confi_lower[1,i], confi_higher[1,i]))
+        page.content <- paste0(page.content, sprintf("</td><td class=\"tdata centeralign topcontentborder\">%.*f-%.*f</td>", digits.ci, confi_lower[1,i], digits.ci, confi_higher[1,i]))
       }
       else {
         page.content <- paste0(page.content, "</td>")
@@ -450,15 +490,15 @@ sjt.glm <- function (...,
     }
     else {
       # open table cell for Beta-coefficient
-      page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign topcontentborder\">%.2f", coeffs[1,i]))
+      page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign topcontentborder\">%.*f", digits.est, coeffs[1,i]))
       # confidence interval in Beta-column
-      if (showConfInt) page.content <- paste0(page.content, sprintf(" (%.2f-%.2f)", confi_lower[1,i], confi_higher[1,i]))
+      if (showConfInt) page.content <- paste0(page.content, sprintf("%s(%.*f-%.*f)", linebreakstring, digits.ci, confi_lower[1,i], digits.ci, confi_higher[1,i]))
       # if p-values are not shown as numbers, insert them after beta-value
       if (!pvaluesAsNumbers) page.content <- paste0(page.content, sprintf(" %s", pv[1,i]))
       page.content <- paste0(page.content, "</td>")
     }
     # show std. error
-    if (showStdError) page.content <- paste0(page.content, sprintf("<td class=\"tdata centeralign topcontentborder\">%s</td>", se[1,i]))
+    if (showStdError) page.content <- paste0(page.content, sprintf("<td class=\"tdata centeralign topcontentborder\">%.*f</td>", digits.se, se[1,i]))
     # show p-values as numbers in separate column
     if (pvaluesAsNumbers) page.content <- paste0(page.content, sprintf("<td class=\"tdata centeralign topcontentborder\">%s</td>", pv[1,i]))
   }
@@ -473,12 +513,12 @@ sjt.glm <- function (...,
       # confidence interval in separate column
       if (separateConfColumn) {
         # open table cell for Beta-coefficient
-        page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign\">%.2f", coeffs[i+1,j]))
+        page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign\">%.*f", digits.est, coeffs[i+1,j]))
         # if p-values are not shown as numbers, insert them after beta-value
         if (!pvaluesAsNumbers) page.content <- paste0(page.content, sprintf(" %s", pv[i+1,j]))
         # if we have CI, start new table cell (CI in separate column)
         if (showConfInt) {
-          page.content <- paste0(page.content, sprintf("</td><td class=\"tdata centeralign\">%.2f-%.2f</td>", confi_lower[i+1,j], confi_higher[i+1,j]))
+          page.content <- paste0(page.content, sprintf("</td><td class=\"tdata centeralign\">%.*f-%.*f</td>", digits.ci, confi_lower[i+1,j], digits.ci, confi_higher[i+1,j]))
         }
         else {
           page.content <- paste0(page.content, "</td>")
@@ -486,17 +526,17 @@ sjt.glm <- function (...,
       }
       else {
         # open table cell for Beta-coefficient
-        page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign\">%.2f", coeffs[i+1,j]))
+        page.content <- paste0(page.content, sprintf("\n    <td class=\"tdata centeralign\">%.*f", digits.est, coeffs[i+1,j]))
         # confidence interval in Beta-column
-        if (showConfInt) page.content <- paste0(page.content, sprintf(" (%.2f-%.2f)", confi_lower[i+1,j], confi_higher[i+1,j]))
+        if (showConfInt) page.content <- paste0(page.content, sprintf("%s(%.*f-%.*f)", linebreakstring, digits.ci, confi_lower[i+1,j], digits.ci, confi_higher[i+1,j]))
         # if p-values are not shown as numbers, insert them after beta-value
         if (!pvaluesAsNumbers) page.content <- paste0(page.content, sprintf(" %s", pv[i+1,j]))
         page.content <- paste0(page.content, "</td>")
       }
       # show std. error
-      if (showStdError) page.content <- paste0(page.content, sprintf("<td class=\"tdata centeralign\">%s</td>", se[i+1,j]))
+      if (showStdError) page.content <- paste0(page.content, sprintf("<td class=\"tdata centeralign\">%.*f</td>", digits.se, se[i+1,j]))
       # show p-values as numbers in separate column
-      if (pvaluesAsNumbers) page.content <- paste0(page.content, sprintf("<td class=\"tdata\">%s</td>", pv[i+1,j]))
+      if (pvaluesAsNumbers) page.content <- paste0(page.content, sprintf("<td class=\"tdata centeralign\">%s</td>", pv[i+1,j]))
     }
     page.content <- paste0(page.content, "\n  </tr>")
   }
@@ -524,7 +564,7 @@ sjt.glm <- function (...,
     page.content <- paste0(page.content, "  <tr>\n    <td class=\"tdata leftalign summary\">Pseudo-R<sup>2</sup></td>\n")
     for (i in 1:length(input_list)) {
       psr <- PseudoR2(input_list[[i]])
-      page.content <- paste0(page.content, sprintf("    %sR<sup>2</sup><sub>CS</sub> = %.3f<br>R<sup>2</sup><sub>N</sub> = %.3f</td>\n", colspanstring, psr[2], psr[3]))
+      page.content <- paste0(page.content, sprintf("    %sR<sup>2</sup><sub>CS</sub> = %.*f<br>R<sup>2</sup><sub>N</sub> = %.*f</td>\n", colspanstring, digits.summary, psr[2], digits.summary, psr[3]))
     }
     page.content <- paste(page.content, "  </tr>\n")
   }
@@ -535,7 +575,7 @@ sjt.glm <- function (...,
     page.content <- paste0(page.content, "  <tr>\n    <td class=\"tdata leftalign summary\">-2 Log-Likelihood</td>\n")
     for (i in 1:length(input_list)) {
       psr <- PseudoR2(input_list[[i]])
-      page.content <- paste0(page.content, sprintf("    %s%.3f</td>\n", colspanstring, -2*logLik(input_list[[i]])))
+      page.content <- paste0(page.content, sprintf("    %s%.*f</td>\n", colspanstring, digits.summary, -2*logLik(input_list[[i]])))
     }
     page.content <- paste0(page.content, "  </tr>\n")
   }
@@ -545,7 +585,7 @@ sjt.glm <- function (...,
   if (showAIC) {
     page.content <- paste0(page.content, "  <tr>\n    <td class=\"tdata leftalign summary\">AIC</td>\n")
     for (i in 1:length(input_list)) {
-      page.content <- paste0(page.content, sprintf("    %s%.2f</td>\n", colspanstring, AIC(input_list[[i]])))
+      page.content <- paste0(page.content, sprintf("    %s%.*f</td>\n", colspanstring, digits.summary, AIC(input_list[[i]])))
     }
     page.content <- paste0(page.content, "  </tr>\n")
   }
@@ -555,7 +595,7 @@ sjt.glm <- function (...,
   if (showChi2) {
     page.content <- paste0(page.content, "  <tr>\n    <td class=\"tdata leftalign summary\">&Chi;<sup>2</sup></td>\n")
     for (i in 1:length(input_list)) {
-      page.content <- paste0(page.content, sprintf("    %s%.3f</td>\n", colspanstring, Chisquare.glm(input_list[[i]])))
+      page.content <- paste0(page.content, sprintf("    %s%.*f</td>\n", colspanstring, digits.summary, Chisquare.glm(input_list[[i]])))
     }
     page.content <- paste0(page.content, "  </tr>\n")
   }
